from microbit import *
from time import sleep

FORWARD = 1  # Περιστροφή κινητήρα προς τα εμπρός
REVERSE = 0  # Περιστροφή κινητήρα προς τα πίσω
MOTOR1 = 1   # Ο αριστερός κινητήρας
MOTOR2 = 2   # Ο δεξής κινητήρας

pin0.set_pull(pin0.PULL_UP)  # Αρχικοποίηση του αισθητήρα

# Ενεργοποιεί τον κινητήρα MOTOR1/MOTOR2 με φορά FORWARD/BACKWARD και ταχύτητα 0-100
def motor_on(motor, direction, speed):
    limited_speed = min(max(speed, 0), 100)    # Οριοθέτηση στο διάστημα [0, 100]
    rescaled_speed = (limited_speed*1023)/100  # Αντιστοίχιση στο διάστημα [0, 1023]
    output_speed = round(rescaled_speed)       # Στρογγυλοποίηση με αφαίρεση δεκαδικού μέρους
    
    if motor == MOTOR1:
        if direction == FORWARD:
            pin15.write_analog(output_speed)
            pin16.write_digital(0)
        elif direction == REVERSE:
            pin16.write_analog(output_speed)
            pin15.write_digital(0)
    elif motor == MOTOR2:
        if direction == FORWARD:
            pin13.write_analog(output_speed)
            pin14.write_digital(0)
        elif direction == REVERSE:
            pin14.write_analog(output_speed)
            pin13.write_digital(0)

# Απενεργοποιεί τον κινητήρα MOTOR1/MOTOR2
def motor_off(motor):
    if motor == MOTOR1:
        pin15.write_digital(0)
        pin16.write_digital(0)
    elif motor == MOTOR2:
        pin13.write_digital(0)
        pin14.write_digital(0)

while True:
    if accelerometer.was_gesture('left'):
        while not pin_logo.is_touched():
            if display.read_light_level() > 50:
                motor_on(MOTOR1, FORWARD, 30)
                motor_on(MOTOR2, FORWARD, 30)
                display.show(Image.HAPPY)
            else:
                motor_on(MOTOR1, REVERSE, 100)
                motor_on(MOTOR2, REVERSE, 100)
                display.show(Image.SAD)
                sleep(0.5)
                motor_on(MOTOR1, FORWARD, 60)
                motor_on(MOTOR2, REVERSE, 60)
                sleep(0.15)
                motor_on(MOTOR1, REVERSE, 60)
                motor_on(MOTOR2, FORWARD, 60)
                sleep(0.3)
                motor_on(MOTOR1, FORWARD, 60)
                motor_on(MOTOR2, REVERSE, 60)
                sleep(0.15)
                
        motor_off(MOTOR1)
        motor_off(MOTOR2)
        display.clear()
    
    if accelerometer.was_gesture('right'):
        speed = 30
        image = Image(5,5)
        while not pin_logo.is_touched():
            # Η φωτεινότητα των LED είναι ανάλογη της ταχύτητας
            image.fill(round(speed//10.1))
            display.show(image)
            
            if pin0.read_digital() == 1:
                motor_on(MOTOR1, FORWARD, speed)
                motor_on(MOTOR2, REVERSE, speed/2)
            else:
                motor_on(MOTOR1, REVERSE, speed/2)
                motor_on(MOTOR2, FORWARD, speed)
            
            if button_b.is_pressed() and speed < 100:
                speed = speed + 10
                sleep(0.2)
            elif button_a.is_pressed() and speed > 0:
                speed = speed - 10
                sleep(0.2)
                
        motor_off(MOTOR1)
        motor_off(MOTOR2)
        display.clear()
        
